@@ -321,16 +321,20 @@ class StockDetail( object ):
         info = dict()
         try:
             details = self.get_obv_details().tail(1)
-            info['OBV Value'] = round(details['OBV'].values[0],2)
-            info['OBV Index'] = round(details['OBV Index'].values[0],2)
-            info['OBV Slope'] = round(details['OBV Index Slope'].values[0],2)
-            info['OBV Signal']= details['Signal'][0]
+            info['OBV Value']         = round(details['OBV'].values[0],2)
+            info['OBV Index']         = round(details['OBV Index'].values[0],2)
+            info['OBV Slope']         = round(details['OBV Index Slope'].values[0],2)
+            info['OBV Signal']        = details['Signal'][0]
+            info['Passive Portfolio'] = round(details['Passive Portfolio'].values[0],2)
+            info['Active Portfolio']  = round(details['Passive Portfolio'].values[0],2)
         except:
             log.error("Error calculating OBV Results - {0}".format(self.name))
-            info['OBV Value'] = -999
-            info['OBV Index'] = -999
-            info['OBV Slope'] = -999
-            info['OBV Signal']= ''
+            info['OBV Value']         = -999
+            info['OBV Index']         = -999
+            info['OBV Slope']         = -999
+            info['OBV Signal']        = ''
+            info['Passive Portfolio'] = -999
+            info['Active Portfolio']  = -999
         finally:
             return info
         
@@ -363,6 +367,9 @@ class StockDetail( object ):
             df['OBV Slope/Close Slope'] = df['OBV Slope']/df['Close Slope']
             signal_val                  = 2*df.nlargest(np.round(df.shape[0]*.05,0).astype(int), ['OBV Slope/Close Slope'])['OBV Slope/Close Slope'].mean()
             df['Signal']                = df[['MA Slope', 'OBV Slope','Close Slope']].apply(_get_obv_signal, args = [signal_val,], axis = 1 )
+            backtest                    = backTestStrategy(df,'Signal')[['Passive Portfolio', 'Active Portfolio']]
+            df['Passive Portfolio']     = backtest['Passive Portfolio']
+            df['Active Portfolio']      = backtest['Active Portfolio']
         except:
             log.error("Error calculating OBV details - {0}".format(self.name))
             df['OBV']                   = -999
@@ -374,8 +381,10 @@ class StockDetail( object ):
             df['MA Slope']              = -999
             df['OBV Slope/Close Slope'] = -999
             df['Signal']                = ""
+            df['Passive Portfolio']     = -999
+            df['Active Portfolio']      = -999
         finally:
-            self._add_to_technical_details(df, 'OBV', cols = ['MA Slope', 'OBV Slope', 'Signal'])
+            self._add_to_technical_details(df, 'OBV', cols = ['MA Slope', 'OBV Slope', 'Signal', 'Passive Portfolio', 'Active Portfolio'])
             return df.dropna()
 
     def plot_obv_details( self, data = None, period = None ):
@@ -530,12 +539,16 @@ class StockDetail( object ):
         info = dict()
         try:
             details = self.get_rsi_details().tail(1)
-            info['RSI Value']   = round(details['RSI'][0],2)
-            info['RSI Signal']  = details['RSI Signal'][0]
+            info['RSI Value']           = round(details['RSI'][0],2)
+            info['RSI Signal']          = details['RSI Signal'][0]
+            info['Passive Portfolio']   = round(details['Passive Portfolio'][0],2)
+            info['Active Portfolio']    = round(details['Active Portfolio'][0],2)
         except:
             log.error("Error calculating RSI Results - {0}".format(self.name))
-            info['RSI Value']   = -999
-            info['RSI Signal']  = ""
+            info['RSI Value']           = -999
+            info['RSI Signal']          = ""
+            info['Passive Portfolio']   = -999
+            info['Active Portfolio']    = -999
         finally:
             return info
         
@@ -554,19 +567,24 @@ class StockDetail( object ):
             df['RS']            = df['Avg Gain']/df['Avg Loss']
             df['RSI']           = 100 - 100/(1 + df['RS'])
             df['RSI Signal']    = df.apply(lambda x: 'BUY' if x['RSI']<=30 else 'SELL' if x['RSI']>=70 else "", axis = 1)
+            backtest            = backTestStrategy(df,'RSI Signal')[['Passive Portfolio', 'Active Portfolio']]
+            df['Passive Portfolio'] = backtest['Passive Portfolio']
+            df['Active Portfolio']  = backtest['Active Portfolio']
         except Exception:
             log.error("Error calculating RSI Details - {0}".format(self.name))
-            df['Return']    = -999
-            df['Gain']      = -999
-            df['Loss']      = -999
-            df['Avg Gain']  = -999
-            df['Avg Loss']  = -999
-            df['Avg Volume']= -999
-            df['RS']        = -999
-            df['RSI']       = -999
-            df['RSI Signal']= ""
+            df['Return']            = -999
+            df['Gain']              = -999
+            df['Loss']              = -999
+            df['Avg Gain']          = -999
+            df['Avg Loss']          = -999
+            df['Avg Volume']        = -999
+            df['RS']                = -999
+            df['RSI']               = -999
+            df['RSI Signal']        = ""
+            df['Passive Portfolio'] = -999
+            df['Active Portfolio']  = -999
         finally:
-            self._add_to_technical_details(df, 'RSI', cols = ['RSI', 'RSI Signal'], col_map = {'RSI':'Value','RSI Signal':'Signal'})
+            self._add_to_technical_details(df, 'RSI', cols = ['RSI', 'RSI Signal', 'Passive Portfolio', 'Active Portfolio'], col_map = {'RSI':'Value','RSI Signal':'Signal'})
             return df.dropna()
 
     def plot_rsi_details( self, data = None, period = None ):
@@ -673,14 +691,16 @@ class StockDetail( object ):
             info['Smoothing Period']    = self._smoothing_period()
             info['Lookback Period']     = self._lookback_period()
             try:
-                info['%R'], info['%D'], info['WilliamR Signal']  = self.get_williams_r_details()[2].tail(1)[['%R', '%D', 'WilliamR Signal']].values[0]
+                info['%R'], info['%D'], info['WilliamR Signal'], info['Passive Portfolio'], info['Active Portfolio']  = self.get_williams_r_details()[2].tail(1)[['%R', '%D', 'WilliamR Signal', 'Passive Portfolio', 'Active Portfolio']].values[0]
             except:
-                info['%R'], info['%D'], info['WilliamR Signal']  = -999, -999, ""
+                info['%R'], info['%D'], info['WilliamR Signal'], info['Passive Portfolio'], info['Active Portfolio']  = -999, -999, "", -999,-999
         except:
             log.error("Error calculating William's R Results - {0}".format(self.name))
         finally:
             info['%R'] = round(info['%R'],2)
             info['%D'] = round(info['%D'],2)
+            info['Passive Portfolio'] = round(info['Passive Portfolio'],2)
+            info['Active Portfolio'] = round(info['Active Portfolio'],2)
             return info
         
     def get_bollinger_results(self):
@@ -768,7 +788,9 @@ class StockDetail( object ):
             df['Avg Volume']        = df[['Volume']].rolling(window = lookback_period).mean()
             df['Slope %D']          = slope(df['%D'],smoothing_period)
             df['WilliamR Signal']   = df.apply(lambda row: 'BUY' if row['%D'] < WILLIAM_K_UL and row['Slope %D'] >45 else 'SELL' if row['%D'] > WILLIAM_K_LL and row['Slope %D'] < -45 else '', axis = 1)
-            
+            backtest                = backTestStrategy(df,'WilliamR Signal')[['Passive Portfolio', 'Active Portfolio']]
+            df['Passive Portfolio'] = backtest['Passive Portfolio']
+            df['Active Portfolio']  = backtest['Active Portfolio']
         except:
             log.error("Error calculating William's R - {0}".format(self.name))
             df                      = deepcopy(self.historical_prices)
@@ -779,9 +801,11 @@ class StockDetail( object ):
             df['Avg Volume']        = -999
             df['Slope %D']          = -999
             df['WilliamR Signal']   = ""
+            df['Passive Portfolio'] = -999
+            df['Active Portfolio']  = -999
             return smoothing_period, lookback_period, df
         
-        self._add_to_technical_details(df, 'Williams R', cols = ['%D', '%R', 'WilliamR Signal'], col_map = {'WilliamR Signal':'Signal'})
+        self._add_to_technical_details(df, 'Williams R', cols = ['%D', '%R', 'WilliamR Signal', 'Passive Portfolio', 'Active Portfolio'], col_map = {'WilliamR Signal':'Signal'})
         return smoothing_period, lookback_period, df.dropna()
 
     def plot_williams_r_details( self, data = None, period = None ):
@@ -896,6 +920,9 @@ class StockDetail( object ):
             result['Diff Slope']                                    = slope(result['MACD Line to Indicator Diff (Value)'], 9)
             result['Diff Slope Prev']                               = result['Diff Slope'].shift(1)
             result['MACD Signal']                                   = result.apply(lambda row: 'BUY' if row['MACD Line to Indicator Diff (Value)'] < 0 and row['Diff Slope'] > 0 and row['Diff Slope Prev'] < 0 else 'SELL' if row['MACD Line to Indicator Diff (Value)'] > 0 and row['Diff Slope'] < 0 and row['Diff Slope Prev'] > 0 else '', axis = 1)
+            backtest                                                = backTestStrategy(result,'MACD Signal')[['Passive Portfolio', 'Active Portfolio']]
+            result['Passive Portfolio']                             = backtest['Passive Portfolio']
+            result['Active Portfolio']                              = backtest['Active Portfolio']
         except:
             log.error("Error generating MacD details - {0}".format(self.name))
             result                                                  = deepcopy(self.historical_prices)
@@ -908,8 +935,10 @@ class StockDetail( object ):
             result['Diff Slope']                                    = -999
             result['Diff Slope Prev']                               = -999
             result['MACD Signal']                                   = ""
+            result['Passive Portfolio']                             = -999
+            result['Active Portfolio']                              = -999
         finally:
-            self._add_to_technical_details(result, 'MACD', cols = ['MACD Signal', 'MACD Line to Indicator Diff (Value)'], col_map = {'MACD Signal':'Signal', 'MACD Line to Indicator Diff (Value)':'Diff Value'})
+            self._add_to_technical_details(result, 'MACD', cols = ['MACD Signal', 'MACD Line to Indicator Diff (Value)', 'Passive Portfolio', 'Active Portfolio'], col_map = {'MACD Signal':'Signal', 'MACD Line to Indicator Diff (Value)':'Diff Value'})
             result = result.dropna()
             return result
     
@@ -1019,7 +1048,7 @@ class StockDetail( object ):
     def get_macd_results(self):
         info = dict()
         try:
-            info['MACD Line'], info['MACD Indicator'], info['MACD Line to Indicator Diff (Value)'], info['MACD Line to Indicator Diff (Days)'], info['MACD Line to Indicator Diff Rolling Peak'], info['MACD Line to Indicator Diff Rolling Peak per'], info['MACD Signal'] = self.get_macd_details().tail(1)[['MACD Line', 'MACD Indicator', 'MACD Line to Indicator Diff (Value)', 'MACD Line to Indicator Diff (Days)', 'MACD Line to Indicator Diff Rolling Peak', 'MACD Line to Indicator Diff Rolling Peak per', 'MACD Signal']].values[0]
+            info['MACD Line'], info['MACD Indicator'], info['MACD Line to Indicator Diff (Value)'], info['MACD Line to Indicator Diff (Days)'], info['MACD Line to Indicator Diff Rolling Peak'], info['MACD Line to Indicator Diff Rolling Peak per'], info['MACD Signal'], info['Passive Portfolio'], info['Active Portfolio'] = self.get_macd_details().tail(1)[['MACD Line', 'MACD Indicator', 'MACD Line to Indicator Diff (Value)', 'MACD Line to Indicator Diff (Days)', 'MACD Line to Indicator Diff Rolling Peak', 'MACD Line to Indicator Diff Rolling Peak per', 'MACD Signal', 'Passive Portfolio', 'Active Portfolio']].values[0]
         except:
             log.error("Error generating MacD results - {0}".format(self.name))
             info['MACD Line'], info['MACD Indicator'], info['MACD Line to Indicator Diff (Value)'], info['MACD Line to Indicator Diff (Days)'], info['MACD Line to Indicator Diff Rolling Peak'], info['MACD Line to Indicator Diff Rolling Peak per'], info['MACD Signal'] = -1,-1,-1,-1,-1,-1,""
@@ -1029,6 +1058,9 @@ class StockDetail( object ):
             info['MACD Line to Indicator Diff (Value)']          = round(info['MACD Line to Indicator Diff (Value)'],2)
             info['MACD Line to Indicator Diff Rolling Peak']     = round(info['MACD Line to Indicator Diff Rolling Peak'],2)
             info['MACD Line to Indicator Diff Rolling Peak per'] = round(info['MACD Line to Indicator Diff Rolling Peak per'],2)
+            info['Passive Portfolio']                            = round(info['Passive Portfolio'],2)
+            info['Active Portfolio']                             = round(info['Active Portfolio'],2)
+            
             return info
     def _52w_high(self):
         
